@@ -3,10 +3,12 @@ NULL
 
 # #' @importFrom Rcpp sourceCpp evalCpp
 #' @import dplyr
-#' @importFrom purrr map map_df map_dbl map_lgl
-#' @importFrom tibble tibble as_tibble
+#' @importFrom purrr map map_df map_dbl map_lgl pmap
+#' @importFrom tibble tibble as_tibble tribble
 #' @importFrom mlegp mlegp predict.gp
 #' @importFrom rlang UQ sym syms
+#' @importFrom readr col_character col_double col_guess col_factor cols cols_only
+#'        read_csv write_csv read_lines
 NULL
 
 #' @importFrom grDevices adjustcolor colorRampPalette dev.off pdf png rgb
@@ -16,9 +18,11 @@ NULL
 #' @importFrom stats aggregate anova approx coef cor cov lm median na.omit
 #'        nls nls.control optim predict quantile resid rnorm sd setNames
 #' @importFrom utils capture.output download.file read.csv recover write.table
+#'        warnErrList
 #' @importFrom stats plogis qlogis
 NULL
 
+#' @import Rcpp
 #' @useDynLib REddyProc _REddyProc_whichValueGreaterEqualC
 NULL
 
@@ -28,6 +32,9 @@ NULL
 #importFrom(minpack.lm, nlsLM, nls.lm.control)
 
 
+#' @importFrom bigleaf Esat.slope
+NULL
+
 # https://www.r-bloggers.com/re-exporting-the-magrittr-pipe-operator/
 
 # does not work without rd roclet
@@ -39,3 +46,5 @@ NULL
 #' @export
 NULL
 #"%>%" <- magrittr::"%>%"
+
+NULL
